summaryrefslogtreecommitdiff
path: root/sw/qa
diff options
context:
space:
mode:
authoranfanite396 <dipamt1729@gmail.com>2023-08-24 14:59:33 +0530
committerTomaž Vajngerl <quikee@gmail.com>2023-08-25 08:29:57 +0200
commit30b7721f59d9ccfce7e2b40916309adff8ad851c (patch)
treeb765198586dd383a0e81d29c6e28f61c895b36bc /sw/qa
parent3b2d95ab67456c7d7b5e51ffcb664702c6c4d71b (diff)
tdf#45904: Remove old SwXFootnotes Java test
Change-Id: I7444b8521b560c91d2908d14330a3c6d6ff420cb Reviewed-on: https://gerrit.libreoffice.org/c/core/+/156041 Tested-by: Jenkins Reviewed-by: Tomaž Vajngerl <quikee@gmail.com>
Diffstat (limited to 'sw/qa')
-rw-r--r--sw/qa/api/SwXFootnotes.cxx98
-rw-r--r--sw/qa/unoapi/sw_2.sce1
2 files changed, 40 insertions, 59 deletions
diff --git a/sw/qa/unoapi/sw_2.sce b/sw/qa/unoapi/sw_2.sce
index 047870b5ef98..24df90b14ca9 100644
--- a/sw/qa/unoapi/sw_2.sce
+++ b/sw/qa/unoapi/sw_2.sce
@@ -22,7 +22,6 @@
-o sw.SwXFootnote
-o sw.SwXFootnoteProperties
-o sw.SwXFootnoteText
--o sw.SwXFootnotes
-o sw.SwXFrames
-o sw.SwXHeadFootText
-o sw.SwXLineNumberingProperties
diff --git a/sw/qa/api/SwXFootnotes.cxx b/sw/qa/api/SwXFootnotes.cxx
index 5b704500dda0..c04e2be384a4 100644
--- a/sw/qa/api/SwXFootnotes.cxx
+++ b/sw/qa/api/SwXFootnotes.cxx
@@ -7,19 +7,18 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
-#include <test/bootstrapfixture.hxx>
+#include <test/unoapi_test.hxx>
#include <test/container/xelementaccess.hxx>
#include <test/container/xindexaccess.hxx>
-#include <unotest/macros_test.hxx>
#include <com/sun/star/frame/Desktop.hpp>
#include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <com/sun/star/text/XTextDocument.hpp>
-#include <com/sun/star/text/XText.hpp>
#include <com/sun/star/text/XFootnote.hpp>
#include <com/sun/star/text/XFootnotesSupplier.hpp>
+#include <com/sun/star/text/XTextDocument.hpp>
+#include <com/sun/star/text/XText.hpp>
#include <comphelper/processfactory.hxx>
@@ -29,72 +28,55 @@ using namespace css::uno;
namespace
{
/**
* Initial tests for SwXFootnotesText.
*/
-class SwXFootnotesText final : public test::BootstrapFixture,
- public unotest::MacrosTest,
- public apitest::XElementAccess,
- public apitest::XIndexAccess
+class SwXFootnotes final : public UnoApiTest,
+ public apitest::XElementAccess,
+ public apitest::XIndexAccess
{
public:
- SwXFootnotesText();
- virtual void setUp() override;
- void tearDown() override;
+ SwXFootnotes()
+ : UnoApiTest("")
+ , XElementAccess(cppu::UnoType<text::XFootnote>::get())
+ , XIndexAccess(1)
+ {
+ }
- Reference<XInterface> init() override;
+ virtual void setUp() override
+ {
+ UnoApiTest::setUp();
+ mxDesktop.set(frame::Desktop::create(mxComponentContext));
+ mxComponent = loadFromDesktop("private:factory/swriter");
+ CPPUNIT_ASSERT(mxComponent.is());
+ }
- CPPUNIT_TEST_SUITE(SwXFootnotesText);
- CPPUNIT_TEST(testGetElementType);
- CPPUNIT_TEST(testHasElements);
- CPPUNIT_TEST(testGetCount);
- CPPUNIT_TEST(testGetByIndex);
- CPPUNIT_TEST_SUITE_END();
+ Reference<XInterface> init() override
+ {
+ Reference<text::XTextDocument> xTextDocument(mxComponent, UNO_QUERY_THROW);
+ Reference<lang::XMultiServiceFactory> xMSF(mxComponent, UNO_QUERY_THROW);
-private:
- Reference<lang::XComponent> component_;
-};
+ Reference<text::XFootnote> xFootnote(xMSF->createInstance("com.sun.star.text.Footnote"),
+ UNO_QUERY_THROW);
-SwXFootnotesText::SwXFootnotesText()
- : XElementAccess(cppu::UnoType<text::XFootnote>::get())
- , XIndexAccess(1)
-{
-}
+ Reference<text::XText> xText = xTextDocument->getText();
+ Reference<text::XTextCursor> xCursor = xText->createTextCursor();
-void SwXFootnotesText::setUp()
-{
- test::BootstrapFixture::setUp();
- mxDesktop.set(
- frame::Desktop::create(comphelper::getComponentContext(getMultiServiceFactory())));
-}
+ xText->insertTextContent(xCursor, xFootnote, false);
-void SwXFootnotesText::tearDown()
-{
- if (component_.is())
- component_->dispose();
+ Reference<text::XFootnotesSupplier> xSupplier(xTextDocument, UNO_QUERY_THROW);
- test::BootstrapFixture::tearDown();
-}
-
-Reference<XInterface> SwXFootnotesText::init()
-{
- component_ = loadFromDesktop("private:factory/swriter", "com.sun.star.text.TextDocument");
- Reference<text::XTextDocument> xTextDocument(component_, UNO_QUERY_THROW);
- Reference<lang::XMultiServiceFactory> xMSF(component_, UNO_QUERY_THROW);
-
- Reference<text::XFootnote> xFootnote(xMSF->createInstance("com.sun.star.text.Footnote"),
- UNO_QUERY_THROW);
-
- Reference<text::XText> xText = xTextDocument->getText();
- Reference<text::XTextCursor> xCursor = xText->createTextCursor();
-
- xText->insertTextContent(xCursor, xFootnote, false);
-
- Reference<text::XFootnotesSupplier> xSupplier(xTextDocument, UNO_QUERY_THROW);
+ return Reference<XInterface>(xSupplier->getFootnotes(), UNO_QUERY_THROW);
+ }
- return Reference<XInterface>(xSupplier->getFootnotes(), UNO_QUERY_THROW);
-}
+ CPPUNIT_TEST_SUITE(SwXFootnotes);
+ CPPUNIT_TEST(testGetElementType);
+ CPPUNIT_TEST(testHasElements);
+ CPPUNIT_TEST(testGetCount);
+ CPPUNIT_TEST(testGetByIndex);
+ CPPUNIT_TEST_SUITE_END();
+};
-CPPUNIT_TEST_SUITE_REGISTRATION(SwXFootnotesText);
+CPPUNIT_TEST_SUITE_REGISTRATION(SwXFootnotes);
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -29,72 +28,55 @@ using namespace css::uno;
{
/**
- * Initial tests for SwXFootnotesText.
+ * Initial tests for SwXFootnotes.
*/